@@ -2,17 +2,11 @@ use std::cmp::{Ordering, PartialOrd as P};
 use crate::ops::{Value, AsProxy};
 use crate::ops::PartialOrd;
 
-
-
 #[inline]
 fn cmp_i64(value: i64, other: i64) -> Option<Ordering> {
     Some(value.cmp(&other))
 }
 #[inline]
-fn cmp_u64(value: u64, other: u64) -> Option<Ordering> {
-    Some(value.cmp(&other))
-}
-#[inline]
 fn cmp_f64(value: f64, other: f64) -> Option<Ordering> {
     value.partial_cmp(&other)
 }
@@ -20,7 +14,6 @@ fn cmp_f64(value: f64, other: f64) -> Option<Ordering> {
 fn cmp_bool(value: bool, other: bool) -> Option<Ordering> {
     Some(value.cmp(&other))
 }
-
 /**
 PartialOrd
  **/
@@ -37,17 +30,6 @@ fn eq_i64(value: &Value, other: i64) -> Option<Ordering> {
     }
 }
 
-fn eq_u64(value: &Value, other: u64) -> Option<Ordering> {
-    let value = value.u64();
-    if value == other {
-        Some(Ordering::Equal)
-    } else if value > other {
-        Some(Ordering::Greater)
-    } else {
-        Some(Ordering::Less)
-    }
-}
-
 fn eq_f64(value: &Value, other: f64) -> Option<Ordering> {
     let value = value.f64();
     if value == other {
@@ -75,11 +57,14 @@ impl PartialOrd<Value> for Value {
     fn op_partial_cmp(&self, other: &Value) -> Option<Ordering> {
         match self {
             Value::Null => { Some(Ordering::Equal) }
-            Value::Bool(b) => { cmp_bool(*b, other.bool()) }
-            Value::Number(n) => { cmp_f64(n.as_f64().unwrap_or_default(), other.f64()) }
+            Value::Boolean(b) => { cmp_bool(*b, other.bool()) }
+            Value::Int32(n) => { cmp_f64(*n as f64, other.f64()) }
+            Value::Int64(n) => { cmp_f64(*n as f64, other.f64()) }
+            Value::Double(n) => { cmp_f64(*n, other.f64()) }
             Value::String(s) => { Some(s.cmp(&other.string())) }
             Value::Array(_) => { None }
-            Value::Object(_) => { None }
+            Value::Document(_) => { None }
+            _ => {None}
         }
     }
 }
@@ -88,11 +73,14 @@ impl PartialOrd<Value> for &Value {
     fn op_partial_cmp(&self, other: &Value) -> Option<Ordering> {
         match self {
             Value::Null => { Some(Ordering::Equal) }
-            Value::Bool(b) => { cmp_bool(*b, other.bool()) }
-            Value::Number(n) => { cmp_f64(n.as_f64().unwrap_or_default(), other.f64()) }
+            Value::Boolean(b) => { cmp_bool(*b, other.bool()) }
+            Value::Int32(n) => { cmp_f64(*n as f64, other.f64()) }
+            Value::Int64(n) => { cmp_f64(*n as f64, other.f64()) }
+            Value::Double(n) => { cmp_f64(*n, other.f64()) }
             Value::String(s) => { Some(s.cmp(&other.string())) }
             Value::Array(_) => { None }
-            Value::Object(_) => { None }
+            Value::Document(_) => { None }
+            _ => {None}
         }
     }
 }
@@ -101,11 +89,14 @@ impl PartialOrd<&Value> for &Value {
     fn op_partial_cmp(&self, other: &&Value) -> Option<Ordering> {
         match self {
             Value::Null => { Some(Ordering::Equal) }
-            Value::Bool(b) => { cmp_bool(*b, other.bool()) }
-            Value::Number(n) => { cmp_f64(n.as_f64().unwrap_or_default(), other.f64()) }
+            Value::Boolean(b) => { cmp_bool(*b, other.bool()) }
+             Value::Int32(n) => { cmp_f64(*n as f64, other.f64()) }
+            Value::Int64(n) => { cmp_f64(*n as f64, other.f64()) }
+            Value::Double(n) => { cmp_f64(*n, other.f64()) }
             Value::String(s) => { Some(s.cmp(&other.string())) }
             Value::Array(_) => { None }
-            Value::Object(_) => { None }
+            Value::Document(_) => { None }
+            _ => {None}
         }
     }
 }
@@ -114,11 +105,14 @@ impl PartialOrd<&&Value> for &Value {
     fn op_partial_cmp(&self, other: &&&Value) -> Option<Ordering> {
         match self {
             Value::Null => { Some(Ordering::Equal) }
-            Value::Bool(b) => { cmp_bool(*b, other.bool()) }
-            Value::Number(n) => { cmp_f64(n.as_f64().unwrap_or_default(), other.f64()) }
+            Value::Boolean(b) => { cmp_bool(*b, other.bool()) }
+             Value::Int32(n) => { cmp_f64(*n as f64, other.f64()) }
+            Value::Int64(n) => { cmp_f64(*n as f64, other.f64()) }
+            Value::Double(n) => { cmp_f64(*n, other.f64()) }
             Value::String(s) => { Some(s.cmp(&other.string())) }
             Value::Array(_) => { None }
-            Value::Object(_) => { None }
+            Value::Document(_) => { None }
+            _ => {None}
         }
     }
 }
@@ -127,11 +121,14 @@ impl PartialOrd<&Value> for Value {
     fn op_partial_cmp(&self, other: &&Value) -> Option<Ordering> {
         match self {
             Value::Null => { Some(Ordering::Equal) }
-            Value::Bool(b) => { cmp_bool(*b, other.bool()) }
-            Value::Number(n) => { cmp_f64(n.as_f64().unwrap_or_default(), other.f64()) }
+            Value::Boolean(b) => { cmp_bool(*b, other.bool()) }
+             Value::Int32(n) => { cmp_f64(*n as f64, other.f64()) }
+            Value::Int64(n) => { cmp_f64(*n as f64, other.f64()) }
+            Value::Double(n) => { cmp_f64(*n, other.f64()) }
             Value::String(s) => { Some(s.cmp(&other.string())) }
             Value::Array(_) => { None }
-            Value::Object(_) => { None }
+            Value::Document(_) => { None }
+            _ => {None}
         }
     }
 }
@@ -140,11 +137,14 @@ impl PartialOrd<&&Value> for Value {
     fn op_partial_cmp(&self, other: &&&Value) -> Option<Ordering> {
         match self {
             Value::Null => { Some(Ordering::Equal) }
-            Value::Bool(b) => { cmp_bool(*b, other.bool()) }
-            Value::Number(n) => { cmp_f64(n.as_f64().unwrap_or_default(), other.f64()) }
+            Value::Boolean(b) => { cmp_bool(*b, other.bool()) }
+             Value::Int32(n) => { cmp_f64(*n as f64, other.f64()) }
+            Value::Int64(n) => { cmp_f64(*n as f64, other.f64()) }
+            Value::Double(n) => { cmp_f64(*n, other.f64()) }
             Value::String(s) => { Some(s.cmp(&other.string())) }
             Value::Array(_) => { None }
-            Value::Object(_) => { None }
+            Value::Document(_) => { None }
+            _ => {None}
         }
     }
 }
@@ -188,7 +188,6 @@ macro_rules! impl_numeric_cmp {
 
 impl_numeric_cmp! {
     eq_i64[i8 i16 i32 i64 isize]
-    eq_u64[u8 u16 u32 u64 usize]
     eq_f64[f32 f64]
     eq_bool[bool]
 }
@@ -222,5 +221,4 @@ impl PartialOrd<&$ty> for &$ty{
 }
 
 cmp_self!(cmp_i64[i8 i16 i32 i64 isize]);
-cmp_self!(cmp_u64[u8 u16 u32 u64 usize]);
 cmp_self!(cmp_f64[f32 f64]);
\ No newline at end of file
