@@ -7,7 +7,7 @@ impl Not for Value {
 
     fn op_not(self) -> Self::Output {
         match self {
-            serde_json::Value::Bool(b) => { !b }
+            Value::Boolean(b) => { !b }
             _ => { true }
         }
     }
@@ -17,7 +17,7 @@ impl Not for &Value {
     type Output = bool;
     fn op_not(self) -> Self::Output {
         match self {
-            serde_json::Value::Bool(b) => { !*b }
+            Value::Boolean(b) => { !*b }
             _ => { true }
         }
     }
@@ -27,7 +27,7 @@ impl Not for &mut Value {
     type Output = bool;
     fn op_not(self) -> Self::Output {
         match self {
-            serde_json::Value::Bool(b) => { !*b }
+            Value::Boolean(b) => { !*b }
             _ => { true }
         }
     }
