@@ -2,25 +2,25 @@ use crate::ops::Value;
 use crate::ops::Rem;
 use crate::ops::AsProxy;
 
-
-
 //value
-
 impl Rem<Value> for Value {
     type Output = Value;
     fn op_rem(self, rhs: Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() % rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() % rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() % rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int32(s % rhs);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s % rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s % rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -30,17 +30,20 @@ impl Rem<&Value> for Value {
     type Output = Value;
     fn op_rem(self, rhs: &Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() % rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() % rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() % rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int32(s % rhs);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s % rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s % rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -50,17 +53,20 @@ impl Rem<&&Value> for Value {
     type Output = Value;
     fn op_rem(self, rhs: &&Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() % rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() % rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() % rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int32(s % rhs);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s % rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s % rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -70,17 +76,20 @@ impl Rem<Value> for &Value {
     type Output = Value;
     fn op_rem(self, rhs: Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() % rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() % rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() % rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int32(s % rhs);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s % rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s % rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -90,17 +99,20 @@ impl Rem<&Value> for &Value {
     type Output = Value;
     fn op_rem(self, rhs: &Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() % rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() % rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() % rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int32(s % rhs);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s % rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s % rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -111,17 +123,20 @@ impl Rem<&&Value> for &Value {
     type Output = Value;
     fn op_rem(self, rhs: &&Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() % rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() % rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() % rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int32(s % rhs);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s % rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s % rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -129,28 +144,20 @@ impl Rem<&&Value> for &Value {
 
 
 fn op_rem_i64(value: &Value, other: i64) -> i64 {
-    value.as_i64().unwrap_or_default() % other
-}
-
-fn op_rem_u64(value: &Value, other: u64) -> u64 {
-    value.as_u64().unwrap_or_default() % other
+    value.i64() % other
 }
 
 fn op_rem_f64(value: &Value, other: f64) -> f64 {
-    value.as_f64().unwrap_or_default() % other
+    value.f64() % other
 }
 
 
 fn op_rem_i64_value(value: &Value, other: i64) -> i64 {
-    other % value.as_i64().unwrap_or_default()
-}
-
-fn op_rem_u64_value(value: &Value, other: u64) -> u64 {
-    other % value.as_u64().unwrap_or_default()
+    other % value.i64()
 }
 
 fn op_rem_f64_value(value: &Value, other: f64) -> f64 {
-    other % value.as_f64().unwrap_or_default()
+    other % value.f64()
 }
 
 
@@ -198,7 +205,6 @@ macro_rules! impl_numeric_rem {
 
 impl_numeric_rem! {
     op_rem_i64,op_rem_i64_value[i8 i16 i32 i64 isize] -> i64
-    op_rem_u64,op_rem_u64_value[u8 u16 u32 u64 usize] -> u64
     op_rem_f64,op_rem_f64_value[f32 f64] -> f64
 }
 
@@ -236,5 +242,4 @@ impl Rem<&$ty> for &$ty{
 }
 
 rem_self!([i8 i16 i32 i64 isize]);
-rem_self!([u8 u16 u32 u64 usize]);
 rem_self!([f32 f64]);
